==> mypy-boto3-forecast-0.2.5.tar.gz: mypy-boto3-forecast-0.2.5/mypy_boto3_forecast/helpers.py <==
"Helper functions for forecast service"

from typing import Any, Dict, Union
import boto3
from boto3.session import Session
from botocore.config import Config
from mypy_boto3_forecast.client import Client
from mypy_boto3_forecast.paginator import (
    ListDatasetGroupsPaginator,
    ListDatasetImportJobsPaginator,
    ListDatasetsPaginator,
    ListForecastExportJobsPaginator,
    ListForecastsPaginator,
    ListPredictorsPaginator,
)

# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def boto3_client(
    session: Session = None,
    region_name: str = None,
    api_version: str = None,
    use_ssl: bool = None,
    verify: Union[str, bool] = None,
    endpoint_url: str = None,
    aws_access_key_id: str = None,
    aws_secret_access_key: str = None,
    aws_session_token: str = None,
    config: Config = None,
) -> Client:
    """
    Equivalent of `boto3.client('forecast')`, returns a correct type.
    """
    kwargs: Dict[str, Any] = {}
    if region_name is not None:
        kwargs["region_name"] = region_name
    if api_version is not None:
        kwargs["api_version"] = api_version
    if use_ssl is not None:
        kwargs["use_ssl"] = use_ssl
    if verify is not None:
        kwargs["verify"] = verify
    if endpoint_url is not None:
        kwargs["endpoint_url"] = endpoint_url
    if aws_access_key_id is not None:
        kwargs["aws_access_key_id"] = aws_access_key_id
    if aws_secret_access_key is not None:
        kwargs["aws_secret_access_key"] = aws_secret_access_key
    if aws_session_token is not None:
        kwargs["aws_session_token"] = aws_session_token
    if config is not None:
        kwargs["config"] = config
    if session is not None:
        return session.client("forecast", **kwargs)
    return boto3.client("forecast", **kwargs)


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_dataset_groups_paginator(client: Client) -> ListDatasetGroupsPaginator:
    """
    Equivalent of `client.get_paginator('list_dataset_groups')`, returns a correct type.
    """
    return client.get_paginator("list_dataset_groups")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_dataset_import_jobs_paginator(
    client: Client,
) -> ListDatasetImportJobsPaginator:
    """
    Equivalent of `client.get_paginator('list_dataset_import_jobs')`, returns a correct type.
    """
    return client.get_paginator("list_dataset_import_jobs")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_datasets_paginator(client: Client) -> ListDatasetsPaginator:
    """
    Equivalent of `client.get_paginator('list_datasets')`, returns a correct type.
    """
    return client.get_paginator("list_datasets")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_forecast_export_jobs_paginator(
    client: Client,
) -> ListForecastExportJobsPaginator:
    """
    Equivalent of `client.get_paginator('list_forecast_export_jobs')`, returns a correct type.
    """
    return client.get_paginator("list_forecast_export_jobs")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_forecasts_paginator(client: Client) -> ListForecastsPaginator:
    """
    Equivalent of `client.get_paginator('list_forecasts')`, returns a correct type.
    """
    return client.get_paginator("list_forecasts")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_predictors_paginator(client: Client) -> ListPredictorsPaginator:
    """
    Equivalent of `client.get_paginator('list_predictors')`, returns a correct type.
    """
    return client.get_paginator("list_predictors")

==> mypy-boto3-forecast-0.2.9.tar.gz: mypy-boto3-forecast-0.2.9/mypy_boto3_forecast/helpers.py <==
"Helper functions for forecast service"

from typing import Any, Dict, Union
import boto3
from boto3.session import Session
from botocore.config import Config
from mypy_boto3_forecast.client import Client
from mypy_boto3_forecast.paginator import (
    ListDatasetGroupsPaginator,
    ListDatasetImportJobsPaginator,
    ListDatasetsPaginator,
    ListForecastExportJobsPaginator,
    ListForecastsPaginator,
    ListPredictorsPaginator,
)

# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def boto3_client(
    session: Session = None,
    region_name: str = None,
    api_version: str = None,
    use_ssl: bool = None,
    verify: Union[str, bool] = None,
    endpoint_url: str = None,
    aws_access_key_id: str = None,
    aws_secret_access_key: str = None,
    aws_session_token: str = None,
    config: Config = None,
) -> Client:
    """
    Equivalent of `boto3.client('forecast')`, returns a correct type.
    """
    kwargs: Dict[str, Any] = {}
    if region_name is not None:
        kwargs["region_name"] = region_name
    if api_version is not None:
        kwargs["api_version"] = api_version
    if use_ssl is not None:
        kwargs["use_ssl"] = use_ssl
    if verify is not None:
        kwargs["verify"] = verify
    if endpoint_url is not None:
        kwargs["endpoint_url"] = endpoint_url
    if aws_access_key_id is not None:
        kwargs["aws_access_key_id"] = aws_access_key_id
    if aws_secret_access_key is not None:
        kwargs["aws_secret_access_key"] = aws_secret_access_key
    if aws_session_token is not None:
        kwargs["aws_session_token"] = aws_session_token
    if config is not None:
        kwargs["config"] = config
    if session is not None:
        return session.client("forecast", **kwargs)
    return boto3.client("forecast", **kwargs)


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_dataset_groups_paginator(client: Client) -> ListDatasetGroupsPaginator:
    """
    Equivalent of `client.get_paginator('list_dataset_groups')`, returns a correct type.
    """
    return client.get_paginator("list_dataset_groups")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_dataset_import_jobs_paginator(client: Client) -> ListDatasetImportJobsPaginator:
    """
    Equivalent of `client.get_paginator('list_dataset_import_jobs')`, returns a correct type.
    """
    return client.get_paginator("list_dataset_import_jobs")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_datasets_paginator(client: Client) -> ListDatasetsPaginator:
    """
    Equivalent of `client.get_paginator('list_datasets')`, returns a correct type.
    """
    return client.get_paginator("list_datasets")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_forecast_export_jobs_paginator(client: Client) -> ListForecastExportJobsPaginator:
    """
    Equivalent of `client.get_paginator('list_forecast_export_jobs')`, returns a correct type.
    """
    return client.get_paginator("list_forecast_export_jobs")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_forecasts_paginator(client: Client) -> ListForecastsPaginator:
    """
    Equivalent of `client.get_paginator('list_forecasts')`, returns a correct type.
    """
    return client.get_paginator("list_forecasts")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_predictors_paginator(client: Client) -> ListPredictorsPaginator:
    """
    Equivalent of `client.get_paginator('list_predictors')`, returns a correct type.
    """
    return client.get_paginator("list_predictors")
